@@ -24,9 +24,7 @@ use redis_async::{client, resp_array};
 async fn main() {
     let addr = env::args()
         .nth(1)
-        .unwrap_or_else(|| "127.0.0.1:6379".to_string())
-        .parse()
-        .expect("Cannot parse Redis connection string");
+        .unwrap_or_else(|| "127.0.0.1:6379".to_string());
 
     let mut connection = client::connect(&addr)
         .await
